#ifndef NT2_INCLUDE_FUNCTIONS_MINMAG_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MINMAG_HPP_INCLUDED

#include <nt2/ieee/include/functions/minmag.hpp>

#endif
